use bitsy_parser::game::Game;
use lazy_static::lazy_static;
use std::sync::Mutex;
use wasm_bindgen::prelude::*;

struct State {
    main:       Option<Game>,
    additional: Option<Game>,
}

lazy_static! {
    static ref STATE: Mutex<State> = Mutex::new(State { main: None, additional: None});
}

// TODO DEDUPE

#[wasm_bindgen]
pub fn load_main(game_data: String) -> String {
    let game = Game::from(game_data);

    if game.is_ok() {
        STATE.lock().unwrap().main = Some(game.unwrap());
        "OK!"
    } else {
        "Could not parse game data"
    }.to_string()
}

#[wasm_bindgen]
pub fn load_additional(game_data: String) -> String {
    let game = Game::from(game_data);

    if game.is_ok() {
        STATE.lock().unwrap().additional = Some(game.unwrap());
        "OK!"
    } else {
        "Could not parse game data"
    }.to_string()
}

#[wasm_bindgen]
pub fn merge() -> String {
    let state = STATE.lock().unwrap();

    if state.main.is_none() || state.additional.is_none() {
        return "".to_string();
    }

    let mut main = state.main.clone().unwrap();
    let additional = state.additional.clone().unwrap();
    main.merge(additional);
    main.dedupe_tiles();
    main.to_string()
}
